@@ -10,14 +10,14 @@ log = logging.getLogger('subtitles')
 
 class PluginPeriscope(object):
     """
-    Search and download subtitles using Periscope by Patrick Dessalle
+    Search and download subtitles using Periscope by Patrick Dessalle 
     (http://code.google.com/p/periscope/).
-
+    
     Example (complete task)::
 
       subs:
         find:
-          path:
+          path: 
             - d:\media\incoming
           regexp: '.*\.(avi|mkv|mp4)$'
           recursive: yes
@@ -25,9 +25,11 @@ class PluginPeriscope(object):
         periscope:
           languages:
             - it
+          alternatives:
             - en
+          overwrite: yes
     """
-
+    
     schema = {
         'type': 'object',
         'properties': {
@@ -44,15 +46,15 @@ class PluginPeriscope(object):
             import periscope
         except ImportError as e:
             log.debug('Error importing Periscope: %s' % e)
-            raise plugin.DependencyError('periscope', 'periscope',
-                                         'Periscope module required. ImportError: %s' % e)
-
-    def subbed(self, filename, exts):
-        for ext in exts:
+            raise plugin.DependencyError('periscope', 'periscope', 
+                                  'Periscope module required. ImportError: %s' % e)
+    
+    def subbed(self, filename):
+        for ext in self.exts:
             if os.path.exists(os.path.splitext(filename)[0] + ext):
                 return True
         return False
-
+    
     def on_task_output(self, task, config):
         """
         Configuration::
@@ -62,36 +64,37 @@ class PluginPeriscope(object):
                 overwrite: If yes it will try to download even for videos that are already subbed. Default: no.
                 subexts: List of subtitles file extensions to check (only useful with overwrite=no). Default: srt, stp, sub, stl, ssa.
         """
-        import periscope
-        psc = periscope.Periscope(tempfile.gettempdir())
-        # to avoid A LOT of info/warnings/errors coming from periscope:
-        logging.getLogger("periscope").setLevel(logging.CRITICAL)
-
         if not task.accepted:
             log.debug('nothing accepted, aborting')
             return
-        langs = [s.encode('utf8') for s in config['languages']]  # unicode warnings in periscope
-        alts = []
-        if 'alternatives' in config:
-            alts = [s.encode('utf8') for s in config['alternatives']]
+        import periscope
+        psc = periscope.Periscope(tempfile.gettempdir())
+        logging.getLogger("periscope").setLevel(logging.CRITICAL)  # LOT of messages otherwise
+        langs = [s.encode('utf8') for s in config['languages']]  # avoid unicode warnings
+        alts = [s.encode('utf8') for s in config.get('alternatives', [])]
         if not config['overwrite']:
-            exts = ['.'+s for s in config['subexts']]
+            self.exts = ['.'+s for s in config['subexts']]
         for entry in task.accepted:
             if not 'location' in entry:
                 entry.reject('is not a local file')
-                continue
-            if '$RECYCLE.BIN' in entry['location']:  # happens in connected network shares
-                entry.reject("is in Windows recycle-bin")
             elif not os.path.exists(entry['location']):
-                entry.reject('file not found')  # periscope works on hashes
-            elif not config['overwrite'] and self.subbed(entry['location'], exts):
+                entry.reject('file not found')
+            elif '$RECYCLE.BIN' in entry['location']:
+                continue  # ignore deleted files in Windows shares
+            elif not config['overwrite'] and self.subbed(entry['location']):
                 entry.reject('cannot overwrite existing subs')
-            elif psc.downloadSubtitle(entry['location'].encode("utf8"), langs):
-                log.info('Subtitles found for %s' % entry['location'])
-            elif alts and psc.downloadSubtitle(entry['location'].encode("utf8"), alts):
-                entry.reject('subtitles found for a second-choice language.')
             else:
-                entry.reject('cannot find any subtitles for now.')
+                try:
+                    if psc.downloadSubtitle(entry['location'].encode("utf8"), langs):
+                        log.info('Subtitles found for %s' % entry['location'])
+                    elif alts and psc.downloadSubtitle(entry['location'].encode("utf8"), alts):
+                        entry.reject('subtitles found for a second-choice language.')
+                    else:
+                        entry.reject('cannot find any subtitles for now.')
+                except Exception as err:
+                    # don't want to abort the entire task for errors in a  
+                    # single video file or for occasional network timeouts
+                    entry.fail(err.message)
 
 
 @event('plugin.register')
